RCFILE_PATH = ".carboncopyrc"

FORCED_IGNORE_PATTERNS = r"^.git/*"
FETCH_URL_PATTERN = r"Fetch URL"
GIT_LINK_PATTERN = r"(?<=git@github.com:)[A-Za-z0-9_\-\.]+/[A-Za-z0-9_\-\.]+"
GIT_EXT_PATTERN = r"\.git$"
